@@ -26,10 +26,10 @@ class CommandHandler(socketserver.BaseRequestHandler):
         should_continue = True
         if command['type'] == 'insert':
             df = recv_df(conn)
-            self.server.cache.append(get_file_path_from_key_path(*command['file_path']), df)
+            self.server.cache.append(get_file_path_from_key_path(*command['key_path']), df)
             send_success(conn)
         elif command['type'] == 'get':
-            file_path = get_file_path_from_key_path(*command['file_path'])
+            file_path = get_file_path_from_key_path(*command['key_path'])
             df = self.server.cache.get_dataframe(file_path, command.get('range_start'), command.get('range_end'), command.get('range_type'))
             if df is None:
                 send_msg(conn, bytes([]))
@@ -39,11 +39,11 @@ class CommandHandler(socketserver.BaseRequestHandler):
             stats = self.get_stats(level=command.get('level'))
             send_msg(conn, json.dumps(stats).encode())
         elif command['type'] == 'unload':
-            file_path = get_file_path_from_key_path(*command['file_path'])
+            file_path = get_file_path_from_key_path(*command['key_path'])
             self.server.cache.unload_file(file_path)
             send_success(conn)
         elif command['type'] == 'load':
-            file_path = get_file_path_from_key_path(*command['file_path'])
+            file_path = get_file_path_from_key_path(*command['key_path'])
             data = self.server.cache.get_file(file_path)
             send_json(conn, length=len(data))
         elif command['type'] == 'close':
